/***************************************************************
* L&L - Labyrinths & Legends
* Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
* 
* Created by BowKenKen
*   URL: https://sourceforge.jp/projects/lnl/
* 
* License is GPL
* 
* ܥץϥե꡼եȥǤ
* ʤϡ Free Software Foundation ɽ
*  GNU ̸ͭѵΡ֥С󣲡
* ϤʹߤγƥС椫餤줫򤷡
* ΥС˽äܥץ
* ۤޤѹ뤳ȤǤޤ
* 
* ܥץͭѤȤϻפޤۤˤäƤϡ
* ԾڤŪŬˤĤƤΰۤݾڤޤ,
* ʤݾڤԤʤޤ
* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
* 
* ʤϡܥץȰ GNU ̸ͭѵ
* μ̤äƤϤǤǤʤϡ
*   Free Software Foundation, Inc.,
*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
* ؼ񤤤Ƥ
* 
* $Id: pet.h,v 1.9 2004/12/08 04:56:17 bowkenken Exp $
***************************************************************/

#ifndef	PET_H
#define	PET_H

/* ڥåȡȤ⡦ */

#include	"mnstr.h"

#define	PET_MAX_N	MBR_MAX_N	/* ѡƥϢƹԤ */

/* ڥåȥåפ¤ƤԤޤ᤿ */
#define	LS_PET_MAX_N	LS_MBR_MAX_N

/* ڥå̾κʸ */
#define	PET_NAME_MAX_LEN	MBR_NAME_MAX_LEN

/* ڥåȥåפΥڥåȤΥ󥸥 */
#define	PET_DUN_LEV	10

typedef mnstr_t	pet_t;
typedef mnstr_kind_t	pet_kind_t;

#endif	/* PET_H */
